struct StylesheetContext {
element: Trusted<HTMLElement>,
source: StylesheetContextSource,
media: Arc<Locked<MediaList>>,
url: ServoUrl,
metadata: Option<Metadata>,
data: Vec<u8>,
document: Trusted<Document>,
shadow_root: Option<Trusted<ShadowRoot>>,
origin_clean: bool,
request_generation_id: Option<RequestGenerationId>,
is_script_blocking: bool,
is_render_blocking: bool,
}Expand description
The context required for asynchronously loading an external stylesheet.
Fields
element: Trusted<HTMLElement>The element that initiated the request.
source: StylesheetContextSourcemedia: Arc<Locked<MediaList>>url: ServoUrlmetadata: Option<Metadata>data: Vec<u8>The response body received to date.
document: Trusted<Document>The node document for elem when the load was initiated.
shadow_root: Option<Trusted<ShadowRoot>>origin_clean: boolrequest_generation_id: Option<RequestGenerationId>A token which must match the generation id of the HTMLLinkElement for it to load the stylesheet.
This is ignored for HTMLStyleElement and imports.
is_script_blocking: boolis_render_blocking: boolImplementations
Sourceimpl StylesheetContext
impl StylesheetContext
fn unminify_css(&mut self, file_url: ServoUrl)
fn empty_stylesheet(&self, document: &Document) -> Arc<Stylesheet>
fn parse( &self, quirks_mode: QuirksMode, shared_lock: SharedRwLock, css_error_reporter: &CSSErrorReporter, loader: ElementStylesheetLoader<'_>, ) -> Arc<Stylesheet>
fn contributes_to_the_styling_processing_model( &self, element: &HTMLElement, ) -> bool
Sourcefn contributes_a_script_blocking_style_sheet(
&self,
element: &HTMLElement,
owner: &dyn StylesheetOwner,
document: &Document,
) -> bool
fn contributes_a_script_blocking_style_sheet( &self, element: &HTMLElement, owner: &dyn StylesheetOwner, document: &Document, ) -> bool
fn decrement_blockers_and_finish_load( self, document: &Document, cx: &mut JSContext, )
fn do_post_parse_tasks( self, success: bool, stylesheet: Arc<Stylesheet>, cx: &mut JSContext, )